summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/oscaraccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/oscar/oscaraccount.h')
-rw-r--r--kopete/protocols/oscar/oscaraccount.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/oscar/oscaraccount.h b/kopete/protocols/oscar/oscaraccount.h
index bccaa9a1..2371a640 100644
--- a/kopete/protocols/oscar/oscaraccount.h
+++ b/kopete/protocols/oscar/oscaraccount.h
@@ -134,16 +134,16 @@ protected:
* Adds a contact to a meta contact
*/
virtual bool createContact(const TQString &contactId,
- Kopete::MetaContact *tqparentContact );
+ Kopete::MetaContact *parentContact );
/**
* Protocols using Oscar must implement this to perform the instantiation
* of their contact for Kopete. Called by @ref createContact().
* @param contactId theprotocol unique id of the contact
* @param tqparentContact the tqparent metacontact
* @return whether the creation succeeded or not
*/
- virtual OscarContact *createNewContact( const TQString &contactId, Kopete::MetaContact *tqparentContact, const SSI& ssiItem ) = 0;
+ virtual OscarContact *createNewContact( const TQString &contactId, Kopete::MetaContact *parentContact, const SSI& ssiItem ) = 0;
virtual TQString sanitizedMessage( const TQString& message ) = 0;
@@ -134,16 +134,16 @@ protected:
* of their contact for Kopete. Called by @ref createContact().
* @param contactId theprotocol unique id of the contact
- * @param tqparentContact the tqparent metacontact
+ * @param parentContact the tqparent metacontact
* @return whether the creation succeeded or not
*/